@@ -1,42 +1,53 @@
-# $Id: TinyClick.pm 52 2007-04-15 15:19:34Z dave $
 package WWW::Shorten::TinyClick;
 
 use strict;
 use warnings;
 
-our $VERSION = '1.90';
+our $VERSION = '3.090';
+$VERSION = eval $VERSION;
+
 require WWW::Shorten::_dead;
 
-0;
-
-__END__
+1;
 
 =head1 NAME
 
-WWW::Shorten::TinyClick - Perl interface to tinyclick.com
+WWW::Shorten::TinyClick - (DEPRECATED) Shorten URLs
 
 =head1 SYNOPSIS
 
-    # No appropriate synopsis.
+  # No appropriate synopsis.
 
 =head1 DESCRIPTION
 
-A Perl interface to the web site tinyclick.com.
-
 Unfortunately, this service became inactive at some point between 1.89
 and 1.90, so this module will merely give you an error if you try to use
 it. Feel free to pick a different L<service|WWW::Shorten>.
 
-=head1 SUPPORT, LICENCE, THANKS and SUCH
-
-See the main L<WWW::Shorten> docs.
-
 =head1 AUTHOR
 
-Iain Truskett <spoon@cpan.org>, Dave Cross <dave@mag-sol.com>
+Iain Truskett C<spoon@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Chase Whitener C<capoeirab@cpan.org>
+
+=item *
+
+Dave Cross C<dave@perlhacks.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+Under the terms and copyright of L<WWW::Shorten>
 
 =head1 SEE ALSO
 
-L<WWW::Shorten>, L<perl>
+L<WWW::Shorten>
 
 =cut
